# AI Ethical Dilemmas Index

## Categories
- [Fairness](categories/fairness)
- [Privacy](categories/privacy)
- [Transparency](categories/transparency)
- [Accountability](categories/accountability)
- [Autonomy](categories/autonomy)
- [Safety](categories/safety)